set -e

cd ~/Desktop
mkdir QEMU
cd QEMU

mkdir Root
export ROOT="$(pwd)/Root"

export PATH+=:"$ROOT/bin"
export CFLAGS="-I$ROOT/include"
export LDFLAGS="-L$ROOT/lib"

curl -L https://pkg-config.freedesktop.org/releases/pkg-config-0.29.2.tar.gz -o pkgconfig.gz
curl -L https://ftp.gnu.org/pub/gnu/gettext/gettext-0.19.8.tar.gz -o gettext.gz
curl -L https://ftp.gnu.org/pub/gnu/libiconv/libiconv-1.15.tar.gz -o libiconv.gz
curl -L ftp://sourceware.org/pub/libffi/libffi-3.2.1.tar.gz -o libffi.gz
curl -L https://ftp.gnome.org/pub/gnome/sources/glib/2.40/glib-2.40.2.tar.xz -o glib.xz
curl -L https://www.cairographics.org/releases/pixman-0.38.0.tar.gz -o pixman.gz
curl -L https://download.qemu.org/qemu-3.1.0.tar.xz -o qemu.xz

tar -xf pkgconfig.gz
tar -xf gettext.gz
tar -xf libiconv.gz
tar -xf libffi.gz
tar -xf pixman.gz
tar -xf glib.xz
tar -xf qemu.xz

mv pkg-config-0.29.2 pkgconfig
mv gettext-0.19.8 gettext
mv libiconv-1.15 libiconv
mv libffi-3.2.1 libffi
mv pixman-0.38.0 pixman
mv glib-2.40.2 glib
mv qemu-3.1.0 qemu

cd pkgconfig
./configure --prefix="$ROOT" --with-internal-glib
make
make install
cd ..

cd gettext
./configure --prefix="$ROOT"
make
make install
cd ..

cd libiconv
./configure --prefix="$ROOT"
make
make install
cd ..

cd libffi
./configure --prefix="$ROOT"
make
make install
cd ..

cd glib
./configure --prefix="$ROOT" --with-libiconv=gnu
make
make install
cd ..

cd pixman
./configure --prefix="$ROOT"
make
make install
cd ..

cd qemu
./configure --prefix="$ROOT" --firmwarepath=firmware
make
make install
cd ..

mkdir Portable
export PORTABLE="$(pwd)/Portable"

cp "$ROOT"/bin/qemu* "$PORTABLE"

cp "$ROOT/lib/libpixman-1.0.dylib" "$PORTABLE"
cp "$ROOT/lib/libgthread-2.0.0.dylib" "$PORTABLE"
cp "$ROOT/lib/libglib-2.0.0.dylib" "$PORTABLE"
cp "$ROOT/lib/libintl.9.dylib" "$PORTABLE"

cp -R "$ROOT/share/qemu" "$PORTABLE/firmware"

for FILE in $(ls -p "$PORTABLE" | grep -v /)
do
	for LIBRARY in libintl.9.dylib libglib-2.0.0.dylib libgthread-2.0.0.dylib libpixman-1.0.dylib
	do
		install_name_tool -change "$ROOT/lib/$LIBRARY" "@executable_path/$LIBRARY" "$PORTABLE/$FILE"
	done
done